==> mingw-w64-i686-flecs-docs-3.1.5-1-any.pkg.tar.zst: mingw32/share/doc/flecs/html/group__query__types.js <==
var group__query__types =
[
    [ "ecs_term_id_t", "structecs__term__id__t.html", [
      [ "flags", "structecs__term__id__t.html#a45fb44df055f90749ad7e46bcbd132ef", null ],
      [ "id", "structecs__term__id__t.html#aced1feb1c6067223b7073401663e6ead", null ],
      [ "name", "structecs__term__id__t.html#a89f4efdaef4aee89cc0daa89e06630b8", null ],
      [ "trav", "structecs__term__id__t.html#a7614a9e39b9be0b23b57d95c0c5f1914", null ]
    ] ],
    [ "ecs_term_t", "structecs__term__t.html", [
      [ "field_index", "structecs__term__t.html#a840990e01c651f3d56e98c38f6d01ce4", null ],
      [ "first", "structecs__term__t.html#a7664d6fb86276df6ba61e65a18c02ba6", null ],
      [ "id", "structecs__term__t.html#a4009fb6e7efa3583173f7b8328cdadc4", null ],
      [ "id_flags", "structecs__term__t.html#a879654f6816f5842baf3db4104c56fd0", null ],
      [ "idr", "structecs__term__t.html#a72d0b795a0350ff7d3b92e738f89cd4c", null ],
      [ "inout", "structecs__term__t.html#ae3485d5a4702985c183d114d817a039d", null ],
      [ "move", "structecs__term__t.html#a8fb4d917d0a0d2cdddecf31e8e13d812", null ],
      [ "name", "structecs__term__t.html#a6fe5488cb3aba0d51f10180443d05618", null ],
      [ "oper", "structecs__term__t.html#aeda19befac5f14bc18e4a81d6779536d", null ],
      [ "second", "structecs__term__t.html#a34827cf50a87f9a3bc28684f03330e98", null ],
      [ "src", "structecs__term__t.html#a71e6de941fcba3904f4f2168d5f2f101", null ]
    ] ],
    [ "ecs_filter_t", "structecs__filter__t.html", [
      [ "dtor", "structecs__filter__t.html#ab9c5c9eb7ac7e7e648dcb7c907f76d8c", null ],
      [ "entity", "structecs__filter__t.html#abbff50c6255a89d4b543a966cc99bf06", null ],
      [ "field_count", "structecs__filter__t.html#a72af994d032cdaa4720c56daabb80eec", null ],
      [ "flags", "structecs__filter__t.html#a84afa5047ed75877e4be07210ea8a0f8", null ],
      [ "iterable", "structecs__filter__t.html#ad347a31be503b66a376bbfda7ac36606", null ],
      [ "owned", "structecs__filter__t.html#a402254610abb55fcb744cfddeea3df6c", null ],
      [ "term_count", "structecs__filter__t.html#a7e5c65b8d9885bca59b92a9bc0b872cc", null ],
      [ "terms", "structecs__filter__t.html#a2a2cb436f77067febcdbab7f7fed499e", null ],
      [ "terms_owned", "structecs__filter__t.html#a93b8887a538dcdfdd00c1a088ed0993a", null ],
      [ "variable_names", "structecs__filter__t.html#ab9a3f809737455699b53ac7354e5d6ca", null ]
    ] ],
    [ "ecs_observer_t", "structecs__observer__t.html", [
      [ "binding_ctx", "structecs__observer__t.html#ae0eb29eac2d7f5518e883d60a8f2b07d", null ],
      [ "binding_ctx_free", "structecs__observer__t.html#aeb31d40dd88ae4222eac350b19ff6862", null ],
      [ "callback", "structecs__observer__t.html#a123de4798b91fd9a2030b5f9f704710f", null ],
      [ "ctx", "structecs__observer__t.html#ac4d01f10673bd8dd82ebf01a719c4b1f", null ],
      [ "ctx_free", "structecs__observer__t.html#a84afc4f1d532a571aba76839b617a375", null ],
      [ "filter", "structecs__observer__t.html#ab0cdcc8b9ce7cab6f88bc06080db66b3", null ],
      [ "is_monitor", "structecs__observer__t.html#ae288532bdd3ee18582d4894bf9e0ecc2", null ],
      [ "is_multi", "structecs__observer__t.html#af0e079cbcf9490e8b0dd9ce63bc8ded5", null ],
      [ "last_event_id", "structecs__observer__t.html#a7ce0980da4892d85c14b17b46e7728ab", null ],
      [ "observable", "structecs__observer__t.html#a44fb3323ae7d3a3e8c506046665963a9", null ],
      [ "register_id", "structecs__observer__t.html#ace1ce75b96d8ee55070eb2d8d0f7d985", null ],
      [ "run", "structecs__observer__t.html#a5f9f1d3295bcb29dda19ad23632daecb", null ],
      [ "term_index", "structecs__observer__t.html#a19fab5d75f4d95173c499b79e2732d51", null ]
    ] ],
    [ "EcsCascade", "group__query__types.html#ga6aabc4b4ba67b341401bbaf5171e25d7", null ],
    [ "EcsDown", "group__query__types.html#gabd910e9e65998f768a85acab8157b756", null ],
    [ "EcsFilter", "group__query__types.html#gaf3a3b33f13db27248b8fc5003135481b", null ],
    [ "EcsIsEntity", "group__query__types.html#ga09bec54adaa139ad9ea70135de9c56cc", null ],
    [ "EcsIsVariable", "group__query__types.html#ga355d628886251e8734498c841a38ce77", null ],
    [ "EcsParent", "group__query__types.html#ga0734589ed85391213f790ee496c1f456", null ],
    [ "EcsSelf", "group__query__types.html#gaf9aa29ad50644f64671fcf8e86700e86", null ],
    [ "EcsTraverseAll", "group__query__types.html#ga6a2d88b20dc15a28fd2fcf8ef56686ad", null ],
    [ "EcsUp", "group__query__types.html#gaf3c02d3e9f54eb530693a07eb04ce826", null ],
    [ "ecs_inout_kind_t", "group__query__types.html#gafc2697d96842ce3de7ec883bd34dd43e", null ],
    [ "ecs_oper_kind_t", "group__query__types.html#gad04a2570c076fbab61972f1874905404", null ],
    [ "ecs_term_id_t", "group__query__types.html#gae8393d9b07f14378e77ddc6d632b605f", null ],
    [ "ecs_inout_kind_t", "group__query__types.html#ga97cedfe0cd996da329fdbe99421d2f29", [
      [ "EcsInOutDefault", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29a8c7a0b6b29bba3a19ca5227ba46268bc", null ],
      [ "EcsInOutNone", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29abbf416f73e9637815bd0ef3f307b78a0", null ],
      [ "EcsInOut", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29a3123f30c74dadad682295334541def02", null ],
      [ "EcsIn", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29ad4e3435bb3041afd3a49cea4171265fc", null ],
      [ "EcsOut", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29a2e829d2be93af11dfceab35986bfd55d", null ]
    ] ],
    [ "ecs_oper_kind_t", "group__query__types.html#gaae44d4393b0c798926af052e06fc10a8", [
      [ "EcsAnd", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8ac420d7c6037d6e863ebdf071acc3f690", null ],
      [ "EcsOr", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a8aab644d240648daef57e3ba3ace32fe", null ],
      [ "EcsNot", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a281d20ac1d7cc65797989adc8e1678b6", null ],
      [ "EcsOptional", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a592420e56d86f33615052846ae87a5da", null ],
      [ "EcsAndFrom", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8aed92d58b0463421d3eb55a5d918e80bc", null ],
      [ "EcsOrFrom", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a9b3e18d43ce5496509904d77c9b83cfb", null ],
      [ "EcsNotFrom", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8ad99490e8e81ebccec91407b189ebd6e3", null ]
    ] ],
    [ "ECS_FILTER_INIT", "group__query__types.html#gaec6d01484af67f9e3527d94e586af133", null ]
];

==> mingw-w64-i686-flecs-docs-3.2.9-1-any.pkg.tar.zst: mingw32/share/doc/flecs/html/group__query__types.js <==
var group__query__types =
[
    [ "ecs_term_id_t", "structecs__term__id__t.html", [
      [ "flags", "structecs__term__id__t.html#a45fb44df055f90749ad7e46bcbd132ef", null ],
      [ "id", "structecs__term__id__t.html#aced1feb1c6067223b7073401663e6ead", null ],
      [ "name", "structecs__term__id__t.html#a838dbcad992f4a97471d4bca0484ff79", null ],
      [ "trav", "structecs__term__id__t.html#a7614a9e39b9be0b23b57d95c0c5f1914", null ]
    ] ],
    [ "ecs_term_t", "structecs__term__t.html", [
      [ "field_index", "structecs__term__t.html#a840990e01c651f3d56e98c38f6d01ce4", null ],
      [ "first", "structecs__term__t.html#a7664d6fb86276df6ba61e65a18c02ba6", null ],
      [ "flags", "structecs__term__t.html#abccb72aa49553b4e7a14552e50c2b4e0", null ],
      [ "id", "structecs__term__t.html#a4009fb6e7efa3583173f7b8328cdadc4", null ],
      [ "id_flags", "structecs__term__t.html#a879654f6816f5842baf3db4104c56fd0", null ],
      [ "idr", "structecs__term__t.html#a72d0b795a0350ff7d3b92e738f89cd4c", null ],
      [ "inout", "structecs__term__t.html#ae3485d5a4702985c183d114d817a039d", null ],
      [ "move", "structecs__term__t.html#a8fb4d917d0a0d2cdddecf31e8e13d812", null ],
      [ "name", "structecs__term__t.html#a6fe5488cb3aba0d51f10180443d05618", null ],
      [ "oper", "structecs__term__t.html#aeda19befac5f14bc18e4a81d6779536d", null ],
      [ "second", "structecs__term__t.html#a34827cf50a87f9a3bc28684f03330e98", null ],
      [ "src", "structecs__term__t.html#a71e6de941fcba3904f4f2168d5f2f101", null ]
    ] ],
    [ "ecs_filter_t", "structecs__filter__t.html", [
      [ "dtor", "structecs__filter__t.html#ab9c5c9eb7ac7e7e648dcb7c907f76d8c", null ],
      [ "entity", "structecs__filter__t.html#abbff50c6255a89d4b543a966cc99bf06", null ],
      [ "field_count", "structecs__filter__t.html#a72af994d032cdaa4720c56daabb80eec", null ],
      [ "flags", "structecs__filter__t.html#a84afa5047ed75877e4be07210ea8a0f8", null ],
      [ "iterable", "structecs__filter__t.html#ad347a31be503b66a376bbfda7ac36606", null ],
      [ "owned", "structecs__filter__t.html#a402254610abb55fcb744cfddeea3df6c", null ],
      [ "sizes", "structecs__filter__t.html#a37c98a33aa6f8d4c0562c87a2c935d5c", null ],
      [ "term_count", "structecs__filter__t.html#a7e5c65b8d9885bca59b92a9bc0b872cc", null ],
      [ "terms", "structecs__filter__t.html#a2a2cb436f77067febcdbab7f7fed499e", null ],
      [ "terms_owned", "structecs__filter__t.html#a93b8887a538dcdfdd00c1a088ed0993a", null ],
      [ "variable_names", "structecs__filter__t.html#ab9a3f809737455699b53ac7354e5d6ca", null ],
      [ "world", "structecs__filter__t.html#a9b87fbc728c69a2669e06f48d942b492", null ]
    ] ],
    [ "ecs_observer_t", "structecs__observer__t.html", [
      [ "binding_ctx", "structecs__observer__t.html#ae0eb29eac2d7f5518e883d60a8f2b07d", null ],
      [ "binding_ctx_free", "structecs__observer__t.html#aeb31d40dd88ae4222eac350b19ff6862", null ],
      [ "callback", "structecs__observer__t.html#a123de4798b91fd9a2030b5f9f704710f", null ],
      [ "ctx", "structecs__observer__t.html#ac4d01f10673bd8dd82ebf01a719c4b1f", null ],
      [ "ctx_free", "structecs__observer__t.html#a84afc4f1d532a571aba76839b617a375", null ],
      [ "filter", "structecs__observer__t.html#ab0cdcc8b9ce7cab6f88bc06080db66b3", null ],
      [ "is_monitor", "structecs__observer__t.html#ae288532bdd3ee18582d4894bf9e0ecc2", null ],
      [ "is_multi", "structecs__observer__t.html#af0e079cbcf9490e8b0dd9ce63bc8ded5", null ],
      [ "last_event_id", "structecs__observer__t.html#a7ce0980da4892d85c14b17b46e7728ab", null ],
      [ "observable", "structecs__observer__t.html#a44fb3323ae7d3a3e8c506046665963a9", null ],
      [ "register_id", "structecs__observer__t.html#ace1ce75b96d8ee55070eb2d8d0f7d985", null ],
      [ "run", "structecs__observer__t.html#a5f9f1d3295bcb29dda19ad23632daecb", null ],
      [ "term_index", "structecs__observer__t.html#a19fab5d75f4d95173c499b79e2732d51", null ]
    ] ],
    [ "EcsCascade", "group__query__types.html#ga6aabc4b4ba67b341401bbaf5171e25d7", null ],
    [ "EcsDesc", "group__query__types.html#ga651e2c2cad49754b262f2966bf75fa8d", null ],
    [ "EcsDown", "group__query__types.html#gabd910e9e65998f768a85acab8157b756", null ],
    [ "EcsFilter", "group__query__types.html#gaf3a3b33f13db27248b8fc5003135481b", null ],
    [ "EcsIsEntity", "group__query__types.html#ga09bec54adaa139ad9ea70135de9c56cc", null ],
    [ "EcsIsName", "group__query__types.html#ga357bd83de2be483db2ca40bba8b8d84c", null ],
    [ "EcsIsVariable", "group__query__types.html#ga355d628886251e8734498c841a38ce77", null ],
    [ "EcsParent", "group__query__types.html#ga0734589ed85391213f790ee496c1f456", null ],
    [ "EcsSelf", "group__query__types.html#gaf9aa29ad50644f64671fcf8e86700e86", null ],
    [ "EcsTraverseAll", "group__query__types.html#ga6a2d88b20dc15a28fd2fcf8ef56686ad", null ],
    [ "EcsUp", "group__query__types.html#gaf3c02d3e9f54eb530693a07eb04ce826", null ],
    [ "ecs_inout_kind_t", "group__query__types.html#gafc2697d96842ce3de7ec883bd34dd43e", null ],
    [ "ecs_oper_kind_t", "group__query__types.html#gad04a2570c076fbab61972f1874905404", null ],
    [ "ecs_term_id_t", "group__query__types.html#gae8393d9b07f14378e77ddc6d632b605f", null ],
    [ "ecs_inout_kind_t", "group__query__types.html#ga97cedfe0cd996da329fdbe99421d2f29", [
      [ "EcsInOutDefault", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29a8c7a0b6b29bba3a19ca5227ba46268bc", null ],
      [ "EcsInOutNone", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29abbf416f73e9637815bd0ef3f307b78a0", null ],
      [ "EcsInOut", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29a3123f30c74dadad682295334541def02", null ],
      [ "EcsIn", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29ad4e3435bb3041afd3a49cea4171265fc", null ],
      [ "EcsOut", "group__query__types.html#gga97cedfe0cd996da329fdbe99421d2f29a2e829d2be93af11dfceab35986bfd55d", null ]
    ] ],
    [ "ecs_oper_kind_t", "group__query__types.html#gaae44d4393b0c798926af052e06fc10a8", [
      [ "EcsAnd", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8ac420d7c6037d6e863ebdf071acc3f690", null ],
      [ "EcsOr", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a8aab644d240648daef57e3ba3ace32fe", null ],
      [ "EcsNot", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a281d20ac1d7cc65797989adc8e1678b6", null ],
      [ "EcsOptional", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a592420e56d86f33615052846ae87a5da", null ],
      [ "EcsAndFrom", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8aed92d58b0463421d3eb55a5d918e80bc", null ],
      [ "EcsOrFrom", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8a9b3e18d43ce5496509904d77c9b83cfb", null ],
      [ "EcsNotFrom", "group__query__types.html#ggaae44d4393b0c798926af052e06fc10a8ad99490e8e81ebccec91407b189ebd6e3", null ]
    ] ],
    [ "ECS_FILTER_INIT", "group__query__types.html#gaec6d01484af67f9e3527d94e586af133", null ]
];
